<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="en_GB">
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation>Aprire</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvare</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <source>error</source>
        <translation>errore</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file.</source>
        <translation>Errore di scrittura sul file selezionato.</translation>
    </message>
</context>
<context>
    <name>CFormDef</name>
    <message>
        <source>Sail corners coordinates</source>
        <translation>Vela circonda coordinate</translation>
    </message>
    <message>
        <source>tack</source>
        <translation>chiodino</translation>
    </message>
    <message>
        <source>clew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>head</source>
        <translation>testa</translation>
    </message>
    <message>
        <source>peak</source>
        <translation>vetta</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation>IRC misure di ampiezza</translation>
    </message>
</context>
<context>
    <name>CFormDefBase</name>
    <message>
        <source>Sail definition</source>
        <translation>Definizione della vela</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Dimensioni della vela</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <source>Round position</source>
        <translation>Posizione dell&apos;allunamento</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Lunghezza del ghindante</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Lunghezza della base</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Lunghezza della balumina</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Lunghezza del picco</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Allunamento della balumina</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Allunamento del picco</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Allunamento del ghindante</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Allunamento della base</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>deg</translation>
    </message>
    <message>
        <source>Gaff angle from luff</source>
        <translation>Angolo tra picco e ghindante</translation>
    </message>
    <message>
        <source>Rig geometry</source>
        <translation>Geometria dell&apos;attrezzatura</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Base J del triangolo di prua</translation>
    </message>
    <message>
        <source>Tack height</source>
        <translation>Altezza del punto di mura</translation>
    </message>
    <message>
        <source>Distance tack to stem</source>
        <translation>Distanza prua-punto di mura</translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation>Randa</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fiocco</translation>
    </message>
    <message>
        <source>Fore triangle hoist  I</source>
        <translation>Altezza I del triangolo di prua</translation>
    </message>
    <message>
        <source>Boat length LOA</source>
        <translation>Lunghezza della barca</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation>Inclinazione albero/ghindante</translation>
    </message>
    <message>
        <source>Cloth</source>
        <translation>Tessuto vela</translation>
    </message>
    <message>
        <source>Seam width</source>
        <translation>Larghezza vivagno</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Larghezza del tessuto vela</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Taglio</translation>
    </message>
    <message>
        <source>Mitre cut</source>
        <translation>Taglio a spina di pesce</translation>
    </message>
    <message>
        <source>Cross cut</source>
        <translation>Taglio cross-cut</translation>
    </message>
    <message>
        <source>Twist foot</source>
        <translation>Twist foot</translation>
    </message>
    <message>
        <source>Horizontal cut</source>
        <translation>Taglio orizzontale</translation>
    </message>
    <message>
        <source>Number of sections</source>
        <translation>Numero di sezioni</translation>
    </message>
    <message>
        <source>Number of radial gores</source>
        <translation>Numero di pannelli radiali</translation>
    </message>
    <message>
        <source>Radial cut</source>
        <translation>Taglio radiale</translation>
    </message>
    <message>
        <source>Vertical cut</source>
        <translation>Taglio verticale</translation>
    </message>
    <message>
        <source>Sail shape</source>
        <translation>Forma della vela</translation>
    </message>
    <message>
        <source>Top depth</source>
        <translation>Profondita&apos; in alto</translation>
    </message>
    <message>
        <source>Mid depth</source>
        <translation>Profondita&apos; al centro</translation>
    </message>
    <message>
        <source>Foot depth</source>
        <translation>Profondita&apos; alla base</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Angolo di svergolamento</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancellare</translation>
    </message>
    <message>
        <source>Leech hem</source>
        <translation>Vaina balumina</translation>
    </message>
    <message>
        <source>Other hems</source>
        <translation>Altre vaine</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Angolo caduta vela</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <source>Sail area</source>
        <translation>Area della vela</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonale</translation>
    </message>
    <message>
        <source>Compute</source>
        <translation>Calcola</translation>
    </message>
    <message>
        <source>Sail ID</source>
        <translation>Nome della vela</translation>
    </message>
    <message>
        <source>Number of luff gores</source>
        <translation>Numero di ghindante pannelli radiali</translation>
    </message>
    <message>
        <source>Fore triangle base  J</source>
        <translation>  Base J del triangolo di prua</translation>
    </message>
    <message>
        <source>Dihedral angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail identifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>m2</source>
        <translation>m2</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <source>Sailcut CAD Handbook</source>
        <translation>Manuale di Sailcut CAD</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>to &amp;DXF</source>
        <translation>&amp;DXF</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation>vela &amp;TXT</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation>vela &amp;XML</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Aprire</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvare</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Salvare &amp;sotto</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Uscire</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensioni</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation>&amp;Profilo</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation>&amp;Rinforzi</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation>&amp;Attrezzatura</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vista</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>About Sailcut CAD</source>
        <translation>A proposito di Sailcut CAD</translation>
    </message>
    <message>
        <source>error</source>
        <translation>errore</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Errore di scrittura sul file selezionato</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>A proposito di &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Sailcut CAD</source>
        <translation>A proposito di &amp;Sailcut CAD</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Apri &amp;recente</translation>
    </message>
    <message>
        <source>Export &amp;3D sail</source>
        <translation type="obsolete">Esporta &amp;vela 3D</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation>al plotter &amp;Carlson</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation>Esporta &amp;svilupppo</translation>
    </message>
    <message>
        <source>Sailcut CAD &amp;Handbook</source>
        <translation>Manuale &amp;Sailcut CAD</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation>vista in chiaroscuro</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation>vista spigoli</translation>
    </message>
    <message>
        <source>development</source>
        <translation>sviluppo</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation>nuova vela creata</translation>
    </message>
    <message>
        <source>loaded &apos;%1&apos;</source>
        <translation>caricata &apos;%1&apos;</translation>
    </message>
    <message>
        <source>error loading &apos;%1&apos;</source>
        <translation>errore caricamento &apos;%1&apos;</translation>
    </message>
    <message>
        <source>wrote &apos;%1&apos;</source>
        <translation>ha scritto &apos;%1&apos;</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation>Errore di stampa dati</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation>Errore di stampa sviluppo</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation>Errore di stampa disegno</translation>
    </message>
    <message>
        <source>data</source>
        <translation>dati</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation>disegno</translation>
    </message>
    <message>
        <source>develop</source>
        <translation type="obsolete">sviluppa</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Stampa</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="obsolete">Tipo vela</translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation type="obsolete">Randa</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="obsolete">Fiocco</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="obsolete">Taglio vela</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="obsolete">Taglio cross-cut</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Taglio orizzontale</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="obsolete">Taglio radiale</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Taglio twist foot</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="obsolete">Taglio verticale</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="obsolete">Taglio a spina di pesce</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation type="obsolete"> sezioni,   </translation>
    </message>
    <message>
        <source> head gores.</source>
        <translation type="obsolete"> altezza pannelli.</translation>
    </message>
    <message>
        <source>Rig </source>
        <translation type="obsolete">Attrezzatura </translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="obsolete">Lunghezza della barca</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Altezza I del triangolo di prua</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Base J del triangolo di prua</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="obsolete">Posizione X del punto di mura</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="obsolete">Altezza Y del punto di mura</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="obsolete">Dimensioni della vela</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="obsolete">Lunghezza del ghindante</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Angolo tra picco e ghindante</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="obsolete">Lunghezza del picco</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="obsolete">Lunghezza della base</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="obsolete">Lunghezza della balumina</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation type="obsolete">Forma dei bordi</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="obsolete">Allunamento del ghindante</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="obsolete">Allunamento del picco</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="obsolete">Allunamento della balumina</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="obsolete">Allunamento della base</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="obsolete">Posizione allunamento ghindante</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="obsolete">Posizione allunamento picco</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="obsolete">Posizione allunamento balumina</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="obsolete">Posizione allunamento base</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="obsolete">Regolazioni vela</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="obsolete">Angolo di svergolamento</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="obsolete">Angolo caduta vela</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Vivagni e vaine tessuto vela</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="obsolete">Larghezza del tessuto vela</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="obsolete">Larghezza vivagni</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="obsolete">Larghezza vaina balumina</translation>
    </message>
    <message>
        <source>Other hems width</source>
        <translation type="obsolete">Larghezza altre vaine</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="obsolete">Profilo della vela</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="obsolete">Fattore ghindante</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="obsolete">Profondita&apos;</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="obsolete">Fattore balumina</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="obsolete">Profilo superiore</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Profilo mediano ad &quot;h&quot;</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="obsolete">Profilo inferiore</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Inclinazione albero/ghindante</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation>Esporta &amp;vela 3D</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="obsolete">Randa</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="obsolete">deg</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancellare</translation>
    </message>
    <message>
        <source>Vertical repartition</source>
        <translation>Ripartizione verticale</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Profilo della vela</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Profilo superiore</translation>
    </message>
    <message>
        <source>Middle profile</source>
        <translation>Profilo mediano</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Profilo inferiore</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation>Attrezzatura</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation>definizione &amp;vela</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation>vela &amp;3D</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation>Aggiungi vela</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Aprire</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Apri &amp;recente</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvare</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Salvare &amp;sotto</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudere</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>error</source>
        <translation>errore</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Errore di scrittura sul file selezionato</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation>Informazioni vela</translation>
    </message>
    <message>
        <source>file</source>
        <translation>file</translation>
    </message>
    <message>
        <source>name</source>
        <translation>nome</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>error</source>
        <translation>errore</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Errore di lettura dal file selezionato.</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">Il supporto OpenGL non e&apos; disponibile su questo sistema.</translation>
    </message>
</context>
<context>
    <name>CSailPrinter</name>
    <message>
        <source>Sailcut CAD data sheet</source>
        <translation>Scheda dati Sailcut CAD</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation>Randa</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fiocco</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deg</source>
        <translation>deg</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation>Tipo vela</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation>Taglio cross-cut</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation>Taglio orizzontale</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation>Taglio radiale</translation>
    </message>
    <message>
        <source>sections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>head gores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>luff gores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation>Taglio twist foot</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation>Taglio verticale</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation>Taglio a spina di pesce</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation>Taglio vela</translation>
    </message>
    <message>
        <source>Rig</source>
        <translation>Attrezzatura</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation>Lunghezza della barca</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation>Inclinazione albero/ghindante</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation>Posizione X del punto di mura</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation>Altezza Y del punto di mura</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation>Altezza I del triangolo di prua</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation>Base J del triangolo di prua</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Dimensioni della vela</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Lunghezza del ghindante</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Lunghezza della base</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Lunghezza della balumina</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Lunghezza del picco</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation>Angolo tra picco e ghindante</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation>Forma dei bordi</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Allunamento del ghindante</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation>Posizione allunamento ghindante</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Allunamento della base</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation>Posizione allunamento base</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Allunamento della balumina</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation>Posizione allunamento balumina</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Allunamento del picco</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation>Posizione allunamento picco</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation>Regolazioni vela</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Angolo di svergolamento</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Angolo caduta vela</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation>Vivagni e vaine tessuto vela</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Larghezza del tessuto vela</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation>Larghezza vivagni</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation>Larghezza vaina balumina</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Profilo della vela</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation>Fattore ghindante</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Profondita&apos;</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation>Fattore balumina</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Profilo superiore</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation>Profilo mediano ad &quot;h&quot;</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Profilo inferiore</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <source>Display parameters</source>
        <translation>Parametri schermata</translation>
    </message>
    <message>
        <source>elevation</source>
        <translation>elevazione</translation>
    </message>
    <message>
        <source>azimuth</source>
        <translation>azimuth</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlli</translation>
    </message>
    <message>
        <source>Reset view</source>
        <translation>Resettare la vista</translation>
    </message>
    <message>
        <source>Labeling</source>
        <translation>Etichette</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoom avanti</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zoom indietro</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>deg</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Luff shape</source>
        <translation>Forma ghindante</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Profondita&apos;</translation>
    </message>
    <message>
        <source>Leech shape</source>
        <translation>Forma balumina</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>gradi</translation>
    </message>
    <message>
        <source>cord</source>
        <translation>corda</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation>errore</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Errore di lettura dal file selezionato.</translation>
    </message>
</context>
</TS>
